==> cramr_ui_lib-0.0.2.tar.gz: test/model/verb_test_model_test.dart <==
import 'package:test/test.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';

void main() {
  group('Verb Test Model tests', () {
    var model = VerbTestModel();
    model.initialise(["ai", "as", "a", "avons", "avez", "ont"], ["je", "tu", "il", "nous", "vous", "ils"], "fr", "avoir", "hebben");

    test('Some random behaviour tests for the model', () {
      model.add("banana", 3);

      expect(model.isComplete(), false);
      expect(model.score, 0);
      expect(model.items.length, 6);
      expect(model.items[0], "");
      expect(model.items[3], "banana");
      expect(model.pronouns.length, 6);
      expect(model.pronouns[1], "tu");
      expect(model.verb.translation, "hebben");

      model.reset();

      expect(model.items.length, 6);
      expect(model.items[3], "");
      expect(model.verb.translation, "hebben");
    });

    test('Test the trimming of the leading spaces', () {
      model.reset();
      model.add(" leading", 0);
      expect(model.items[0], "leading");
    });

    test('Test the trimming of the trailing spaces', () {
      model.reset();
      model.add("trailing ", 0);
      expect(model.items[0], "trailing");
    });

    test('test the isComplete method, especially with regards to leading and trailing spaces', () {
      model.reset();
      model.add(" leading", 0);
      expect(model.isComplete(), false);
      model.add("trailing ", 1);
      expect(model.isComplete(), false);
      model.add(" ", 2);
      expect(model.isComplete(), false);
      model.add(" ", 3);
      expect(model.isComplete(), false);
      model.add(" ", 4);
      expect(model.isComplete(), false);
      model.add(" ", 5);
      expect(model.isComplete(), false);

      model.add("something", 3);
      expect(model.isComplete(), false);

      model.add(" haha", 4);
      expect(model.isComplete(), false);

      model.add(" haha", 5);
      expect(model.isComplete(), false);

      model.add("dont forget", 2);
      expect(model.isComplete(), true);
    });

  });

}

==> cramr_ui_lib-0.0.3.tar.gz: test/model/verb_test_model_test.dart <==
import 'package:test/test.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';

void main() {
  group('Verb Test Model tests', () {
    var model = VerbTestModel();
    model.initialise(["ai", "as", "a", "avons", "avez", "ont"],
        ["je", "tu", "il", "nous", "vous", "ils"], "fr", "avoir", "hebben");

    test('Some random behaviour tests for the model', () {
      model.add("banana", 3);

      expect(model.isComplete(), false);
      expect(model.score, 0);
      expect(model.items.length, 6);
      expect(model.items[0], "");
      expect(model.items[3], "banana");
      expect(model.pronouns.length, 6);
      expect(model.pronouns[1], "tu");
      expect(model.verb.translation, "hebben");

      model.reset();

      expect(model.items.length, 6);
      expect(model.items[3], "");
      expect(model.verb.translation, "hebben");
    });

    test('Test the trimming of the leading spaces', () {
      model.reset();
      model.add(" leading", 0);
      expect(model.items[0], "leading");
    });

    test('Test the trimming of the trailing spaces', () {
      model.reset();
      model.add("trailing ", 0);
      expect(model.items[0], "trailing");
    });

    test(
        'test the isComplete method, especially with regards to leading and trailing spaces',
        () {
      model.reset();
      model.add(" leading", 0);
      expect(model.isComplete(), false);
      model.add("trailing ", 1);
      expect(model.isComplete(), false);
      model.add(" ", 2);
      expect(model.isComplete(), false);
      model.add(" ", 3);
      expect(model.isComplete(), false);
      model.add(" ", 4);
      expect(model.isComplete(), false);
      model.add(" ", 5);
      expect(model.isComplete(), false);

      model.add("something", 3);
      expect(model.isComplete(), false);

      model.add(" haha", 4);
      expect(model.isComplete(), false);

      model.add(" haha", 5);
      expect(model.isComplete(), false);

      model.add("dont forget", 2);
      expect(model.isComplete(), true);
    });
  });
}
